@@ -130,6 +130,7 @@ typedef enum {
 	NMC_GENERIC_INFO_TYPE_CON_ACTIVE_GENERAL_NAME = 0,
 	NMC_GENERIC_INFO_TYPE_CON_ACTIVE_GENERAL_UUID,
 	NMC_GENERIC_INFO_TYPE_CON_ACTIVE_GENERAL_DEVICES,
+	NMC_GENERIC_INFO_TYPE_CON_ACTIVE_GENERAL_IP_IFACE,
 	NMC_GENERIC_INFO_TYPE_CON_ACTIVE_GENERAL_STATE,
 	NMC_GENERIC_INFO_TYPE_CON_ACTIVE_GENERAL_DEFAULT,
 	NMC_GENERIC_INFO_TYPE_CON_ACTIVE_GENERAL_DEFAULT6,
@@ -215,6 +216,11 @@ typedef enum {
 	NMC_GENERIC_INFO_TYPE_DEVICE_DETAIL_WIFI_PROPERTIES_IBSS_RSN,
 	_NMC_GENERIC_INFO_TYPE_DEVICE_DETAIL_WIFI_PROPERTIES_NUM,
 
+	NMC_GENERIC_INFO_TYPE_DEVICE_DETAIL_INTERFACE_FLAGS_UP = 0,
+	NMC_GENERIC_INFO_TYPE_DEVICE_DETAIL_INTERFACE_FLAGS_LOWER_UP,
+	NMC_GENERIC_INFO_TYPE_DEVICE_DETAIL_INTERFACE_FLAGS_CARRIER,
+	_NMC_GENERIC_INFO_TYPE_DEVICE_DETAIL_INTERFACE_FLAGS_NUM,
+
 } NmcGenericInfoType;
 
 #define NMC_HANDLE_COLOR(color) \
