@@ -24,12 +24,9 @@ _ec2_base (void)
 again:
 	base = g_atomic_pointer_get (&base_cached);
 	if (G_UNLIKELY (!base)) {
-
 		/* The base URI can be set via environment variable.
-		 * This is mainly for testing, it's not usually supposed to be configured.
-		 * Consider this private API! */
-		base = g_getenv (NMCS_ENV_VARIABLE ("NM_CLOUD_SETUP_EC2_HOST"));
-
+		 * This is only for testing, not really to be configurable! */
+		base = g_getenv ("NM_CLOUD_SETUP_EC2_HOST");
 		if (   base
 		    && base[0]
 		    && !strchr (base, '/')) {
@@ -484,7 +481,7 @@ _get_config_metadata_ready_check (long response_code,
 		if (!response_parsed)
 			response_parsed = g_hash_table_new_full (nm_str_hash, g_str_equal, g_free, g_free);
 
-		mac_data = g_malloc (sizeof (GetConfigMetadataMac) + 1 + p_start_l);
+		mac_data = g_malloc (sizeof (GetConfigMetadataData) + 1 + p_start_l);
 		mac_data->iface_idx = iface_idx_counter++;
 		memcpy (mac_data->path, p_start, p_start_l);
 		mac_data->path[p_start_l] = '\0';
@@ -548,8 +545,7 @@ nmcs_provider_ec2_class_init (NMCSProviderEC2Class *klass)
 {
 	NMCSProviderClass *provider_class = NMCS_PROVIDER_CLASS (klass);
 
-	provider_class->_name                 = "ec2";
-	provider_class->_env_provider_enabled = NMCS_ENV_VARIABLE ("NM_CLOUD_SETUP_EC2");
-	provider_class->detect                = detect;
-	provider_class->get_config            = get_config;
+	provider_class->_name      = "ec2";
+	provider_class->detect     = detect;
+	provider_class->get_config = get_config;
 }
