@@ -20,22 +20,9 @@
 
 #define NM_MODEM_BROADBAND_MODEM "modem"
 
-static gboolean
-MODEM_CAPS_3GPP (MMModemCapability caps)
-{
-	G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-	/* MM_MODEM_CAPABILITY_LTE_ADVANCED is marked as deprecated since ModemManager 1.14.0.
-	 *
-	 * The flag probably was never used, it certainly isn't used since 1.14.0.
-	 *
-	 * Still, just to be sure, there is no harm in checking it here. Suppress the
-	 * warning, it should have no bad effect.
-	 */
-	return NM_FLAGS_ANY (caps, (  MM_MODEM_CAPABILITY_GSM_UMTS
-	                            | MM_MODEM_CAPABILITY_LTE
-	                            | MM_MODEM_CAPABILITY_LTE_ADVANCED));
-	G_GNUC_END_IGNORE_DEPRECATIONS
-}
+#define MODEM_CAPS_3GPP(caps) (caps & (MM_MODEM_CAPABILITY_GSM_UMTS |    \
+                                       MM_MODEM_CAPABILITY_LTE |         \
+                                       MM_MODEM_CAPABILITY_LTE_ADVANCED))
 
 #define MODEM_CAPS_3GPP2(caps) (caps & (MM_MODEM_CAPABILITY_CDMA_EVDO))
 
@@ -561,7 +548,7 @@ connect_context_step (NMModemBroadband *self)
 	switch (ctx->step) {
 	case CONNECT_STEP_FIRST:
 		ctx->step++;
-		/* fall-through */
+		/* fall through */
 
 	case CONNECT_STEP_WAIT_FOR_SIM:
 		if (MODEM_CAPS_3GPP (ctx->caps) && !self->_priv.sim_iface) {
@@ -569,7 +556,7 @@ connect_context_step (NMModemBroadband *self)
 			break;
 		}
 		ctx->step++;
-		/* fall-through */
+		/* fall through */
 
 	case CONNECT_STEP_UNLOCK:
 		if (   MODEM_CAPS_3GPP (ctx->caps)
@@ -590,7 +577,7 @@ connect_context_step (NMModemBroadband *self)
 			break;
 		}
 		ctx->step++;
-		/* fall-through */
+		/* fall through */
 	case CONNECT_STEP_WAIT_FOR_READY: {
 		GError *error = NULL;
 
@@ -600,9 +587,6 @@ connect_context_step (NMModemBroadband *self)
 		if (!try_create_connect_properties (self))
 			break;
 
-		if (!self->_priv.ctx)
-			break;
-
 		/* Build up list of IP types that we need to use in the retries */
 		ctx->ip_types = nm_modem_get_connection_ip_type (NM_MODEM (self), ctx->connection, &error);
 		if (!ctx->ip_types) {
@@ -618,7 +602,7 @@ connect_context_step (NMModemBroadband *self)
 
 		ctx->step++;
 	}
-		/* fall-through */
+		/* fall through */
 	case CONNECT_STEP_CONNECT:
 		if (!ctx->connect_properties)
 			break;
@@ -652,7 +636,7 @@ connect_context_step (NMModemBroadband *self)
 		}
 
 		ctx->step++;
-		/* fall-through */
+		/* fall through */
 
 	case CONNECT_STEP_LAST:
 		if (self->_priv.ipv4_config || self->_priv.ipv6_config)
