@@ -219,6 +219,7 @@ extern char *_nm_config_match_env;
 
 #define NM_CONFIG_DEVICE_STATE_DIR ""NMRUNDIR"/devices"
 
+#define NM_CONFIG_DEFAULT_MAIN_AUTH_POLKIT_BOOL     (nm_streq (""NM_CONFIG_DEFAULT_MAIN_AUTH_POLKIT, "true"))
 #define NM_CONFIG_DEFAULT_LOGGING_AUDIT_BOOL        (nm_streq (""NM_CONFIG_DEFAULT_LOGGING_AUDIT, "true"))
 
 typedef enum {
@@ -258,8 +259,7 @@ gboolean nm_config_device_state_write (int ifindex,
                                        const char *next_server,
                                        const char *root_path);
 
-void nm_config_device_state_prune_stale (GHashTable *preserve_ifindexes,
-                                         NMPlatform *preserve_in_platform);
+void nm_config_device_state_prune_unseen (GHashTable *seen_ifindexes);
 
 const GHashTable *nm_config_device_state_get_all (NMConfig *self);
 const NMConfigDeviceStateData *nm_config_device_state_get (NMConfig *self,
